import{j as t}from"./vendor-motion-k_x_E260.js";import{l as o,L as s,C as e}from"./index-Buswmged.js";import"./vendor-icons-BDy0XSiX.js";import"./vendor-react-BaJ9Uc06.js";function c(){const a=o();return a._loading?t.jsx(s,{label:"Loading config…"}):t.jsxs("div",{className:"space-y-6",children:[t.jsx("h2",{className:"text-lg font-bold",children:"Configuration"}),t.jsx(e,{children:t.jsx("pre",{className:"text-xs text-gray-400 whitespace-pre-wrap overflow-auto max-h-[70vh] font-mono",children:JSON.stringify(a,null,2)})})]})}export{c as default};
